@@ -3,4 +3,4 @@ from .opposablethumbs import OpposableThumbs
 
 def opposablethumb(request):
     ot = OpposableThumbs(request.META["QUERY_STRING"])
-    return ot.response()
+    return ot.get_thumbnail()
